## v0.1.2 (2025-07-07)

### Fix

- unsupport py39
- **config**: change dependencies

### Refactor

- change tag format

## v0.1.1 (2025-07-01)

### Fix

- **qda**: match statement for py39
- **qda**: fix for dtype=int

## v0.1.0 (2025-07-01)

### Feat

- **qda**: add python script for qda functions
- **qda**: add python script for qda solve

### Fix

- **qda**: match pysparq 0.0.2
